==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/Handler.h <==
// public class gnu.java.net.protocol.ftp.Handler

// class file dependencies
// @dep_class f8f1e4c9a99b480c gnu_java_net_protocol_ftp_Handler
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d7e769aebe17520e java_net_URLStreamHandler

// header file dependencies
// @dep_header java_net_URLStreamHandler

#include "java/net/URLStreamHandler.h"

#ifndef _JC_gnu_java_net_protocol_ftp_Handler_H_
#define _JC_gnu_java_net_protocol_ftp_Handler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLConnection$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_Handler$sub_refs	_jc_gnu_java_net_protocol_ftp_Handler$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_Handler$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_Handler$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_Handler$refs	_jc_gnu_java_net_protocol_ftp_Handler$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_Handler$nonrefs	_jc_gnu_java_net_protocol_ftp_Handler$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_Handler$object	_jc_gnu_java_net_protocol_ftp_Handler$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_Handler$vmethods	_jc_gnu_java_net_protocol_ftp_Handler$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_Handler$vtable	_jc_gnu_java_net_protocol_ftp_Handler$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_Handler$vtype	_jc_gnu_java_net_protocol_ftp_Handler$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_Handler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_Handler$object *);

// Virtual methods
extern jint _jc_gnu_java_net_protocol_ftp_Handler$method$getDefaultPort$94b81a636624b3c2(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_Handler$object *);
extern struct _jc_java_net_URLConnection$object *_jc_gnu_java_net_protocol_ftp_Handler$method$openConnection$7768e1cfcb90de35(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_Handler$object *, struct _jc_java_net_URL$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_Handler$method_info$getDefaultPort$94b81a636624b3c2;
extern _jc_method _jc_gnu_java_net_protocol_ftp_Handler$method_info$openConnection$7768e1cfcb90de35;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_Handler$vmethods {
	jint	(*getDefaultPort$94b81a636624b3c2)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_Handler$object *);
	struct _jc_java_net_URLConnection$object	*(*openConnection$7768e1cfcb90de35)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_Handler$object *, struct _jc_java_net_URL$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_Handler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLStreamHandler$vmethods	java_net_URLStreamHandler;
	_jc_gnu_java_net_protocol_ftp_Handler$vmethods	gnu_java_net_protocol_ftp_Handler;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_Handler$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_Handler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_Handler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_Handler$refs {
    _jc_gnu_java_net_protocol_ftp_Handler$sub_refs	gnu_java_net_protocol_ftp_Handler;
    _jc_java_net_URLStreamHandler$sub_refs	java_net_URLStreamHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_Handler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_Handler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLStreamHandler$sub_nonrefs	java_net_URLStreamHandler;
    _jc_gnu_java_net_protocol_ftp_Handler$sub_nonrefs	gnu_java_net_protocol_ftp_Handler;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_Handler$object {
	_jc_gnu_java_net_protocol_ftp_Handler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_Handler$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_Handler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_Handler$vtype _jc_gnu_java_net_protocol_ftp_Handler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_Handler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_Handler$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_Handler_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/Handler.h <==
// public class gnu.java.net.protocol.ftp.Handler

// class file dependencies
// @dep_class f8f1e4c9a99b480c gnu_java_net_protocol_ftp_Handler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d7e769aebe17520e java_net_URLStreamHandler

// header file dependencies
// @dep_header java_net_URLStreamHandler

#include "java/net/URLStreamHandler.h"

#ifndef _JC_gnu_java_net_protocol_ftp_Handler_H_
#define _JC_gnu_java_net_protocol_ftp_Handler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLConnection$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_Handler$sub_refs	_jc_gnu_java_net_protocol_ftp_Handler$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_Handler$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_Handler$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_Handler$refs	_jc_gnu_java_net_protocol_ftp_Handler$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_Handler$nonrefs	_jc_gnu_java_net_protocol_ftp_Handler$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_Handler$object	_jc_gnu_java_net_protocol_ftp_Handler$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_Handler$vmethods	_jc_gnu_java_net_protocol_ftp_Handler$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_Handler$vtable	_jc_gnu_java_net_protocol_ftp_Handler$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_Handler$vtype	_jc_gnu_java_net_protocol_ftp_Handler$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_Handler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_Handler$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_net_protocol_ftp_Handler$method$getDefaultPort$94b81a636624b3c2(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_Handler$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_URLConnection$object *_jc_gnu_java_net_protocol_ftp_Handler$method$openConnection$7768e1cfcb90de35(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_Handler$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_Handler$method_info$getDefaultPort$94b81a636624b3c2;
extern _jc_method _jc_gnu_java_net_protocol_ftp_Handler$method_info$openConnection$7768e1cfcb90de35;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_Handler$vmethods {
	jint	(*getDefaultPort$94b81a636624b3c2)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_Handler$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_URLConnection$object	*(*openConnection$7768e1cfcb90de35)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_Handler$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_Handler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLStreamHandler$vmethods	java_net_URLStreamHandler;
	_jc_gnu_java_net_protocol_ftp_Handler$vmethods	gnu_java_net_protocol_ftp_Handler;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_Handler$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_Handler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_Handler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_Handler$refs {
    _jc_gnu_java_net_protocol_ftp_Handler$sub_refs	gnu_java_net_protocol_ftp_Handler;
    _jc_java_net_URLStreamHandler$sub_refs	java_net_URLStreamHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_Handler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_Handler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLStreamHandler$sub_nonrefs	java_net_URLStreamHandler;
    _jc_gnu_java_net_protocol_ftp_Handler$sub_nonrefs	gnu_java_net_protocol_ftp_Handler;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_Handler$object {
	_jc_gnu_java_net_protocol_ftp_Handler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_Handler$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_Handler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_Handler$vtype _jc_gnu_java_net_protocol_ftp_Handler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_Handler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_Handler$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_Handler_H_ */
